aboutsummaryrefslogtreecommitdiff
path: root/CMAKE
diff options
context:
space:
mode:
authorjulie <julielangou@users.noreply.github.com>2010-12-23 02:32:05 +0000
committerjulie <julielangou@users.noreply.github.com>2010-12-23 02:32:05 +0000
commit7f144b46d47152b1b0ed100978ee35f87aae15e8 (patch)
tree2173affda406ba149b28f1c6a74ffdb3b9abc569 /CMAKE
parent1c2620a72f6f8d1962f66566baf443078a381849 (diff)
1. Added support for both IBM XL Fortran and IBM VisualAge Fortran
2. Added libblas to ESSL libs to cover missing functionality from ESSL 3. Renamed ESSL_6464, ESSL_SMP, and ESSL_SMP_6464 to ESSL6464, ESSLSMP, and ESSLSMP6464 respectively to mimic the actual library names. 4. Added copyright notice to CheckLAPACKCompilerFlags - Chuck Atkins (Kitware)
Diffstat (limited to 'CMAKE')
-rw-r--r--CMAKE/CheckLAPACKCompilerFlags.cmake15
-rw-r--r--CMAKE/FindBLAS.cmake16
2 files changed, 22 insertions, 9 deletions
diff --git a/CMAKE/CheckLAPACKCompilerFlags.cmake b/CMAKE/CheckLAPACKCompilerFlags.cmake
index 6d274f2e..560ee4a3 100644
--- a/CMAKE/CheckLAPACKCompilerFlags.cmake
+++ b/CMAKE/CheckLAPACKCompilerFlags.cmake
@@ -3,6 +3,18 @@
#
# 1. If FPE traps are enabled either abort or disable them
# 2. Specify fixed form if needed
+#
+#=============================================================================
+# Author: Chuck Atkins
+# Copyright 2010 Kitware, Inc.
+#
+# Distributed under the OSI-approved BSD License (the "License");
+# see accompanying file Copyright.txt for details.
+#
+# This software is distributed WITHOUT ANY WARRANTY; without even the
+# implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+# See the License for more information.
+#=============================================================================
macro( CheckLAPACKCompilerFlags )
@@ -33,7 +45,8 @@ elseif( CMAKE_Fortran_COMPILER_ID STREQUAL "SunPro" )
endif()
# IBM XL Fortran
-elseif( CMAKE_Fortran_COMPILER_ID STREQUAL "VisualAge" )
+elseif( (CMAKE_Fortran_COMPILER_ID STREQUAL "VisualAge" ) OR # CMake 2.6
+ (CMAKE_Fortran_COMPILER_ID STREQUAL "XL" ) ) # CMake 2.8
if( "${CMAKE_Fortran_FLAGS}" MATCHES "-qflttrap=[a-zA-Z:]:enable" )
set( FPE_EXIT TRUE )
endif()
diff --git a/CMAKE/FindBLAS.cmake b/CMAKE/FindBLAS.cmake
index 53b76dae..a4e0b675 100644
--- a/CMAKE/FindBLAS.cmake
+++ b/CMAKE/FindBLAS.cmake
@@ -33,9 +33,9 @@
# VECLIB8 - HP's Math Library: VECLIB8 (64 bit integers)
# See http://www.hp.com/go/mlib
# ESSL - IBM's Engineering and Scientific Subroutine Library
# ESSL_6464 - IBM's Engineering and Scientific Subroutine Library (int64)
# ESSL_SMP - IBM's Engineering and Scientific Subroutine Library (smp)
# ESSL_SMP_6464 - (smp + int64)
# See http://www-03.ibm.com/systems/software/essl/
# MKL - Intel Math Kernel Library (dynamic interface)
# Use MKL_THREADING_LAYER and MKL_INTERFACE_LAYER environment vars
@@ -224,20 +224,20 @@ foreach( _BLAS_VENDOR ${BLAS_VENDORS} )
# IBM ESSL
elseif( _BLAS_VENDOR STREQUAL "ESSL" )
message( STATUS "FindBLAS: Searching for IBM ESSL" )
- _BLAS_LOCATE_AND_TEST( ${_BLAS_VENDOR} "essl" "" )
+ _BLAS_LOCATE_AND_TEST( ${_BLAS_VENDOR} "essl;blas" "" )
# IBM ESSL (SMP Version)
- elseif( _BLAS_VENDOR STREQUAL "ESSL_SMP" )
+ elseif( _BLAS_VENDOR STREQUAL "ESSLSMP" )
message( STATUS "FindBLAS: Searching for IBM ESSL (SMP)" )
- _BLAS_LOCATE_AND_TEST( ${_BLAS_VENDOR} "esslsmp" "" )
+ _BLAS_LOCATE_AND_TEST( ${_BLAS_VENDOR} "esslsmp;blas" "" )
# IBM ESSL int64
- elseif( _BLAS_VENDOR STREQUAL "ESSL_6464" )
+ elseif( _BLAS_VENDOR STREQUAL "ESSL6464" )
message( STATUS "FindBLAS: Searching for IBM ESSL (int64)" )
_BLAS_LOCATE_AND_TEST( ${_BLAS_VENDOR} "essl6464" "" )
# IBM ESSL (SMP + int64)
- elseif( _BLAS_VENDOR STREQUAL "ESSL_SMP_6464" )
+ elseif( _BLAS_VENDOR STREQUAL "ESSLSMP6464" )
message( STATUS "FindBLAS: Searching for IBM ESSL (SMP + int64)" )
_BLAS_LOCATE_AND_TEST( ${_BLAS_VENDOR} "esslsmp6464" "" )
@@ -33,9 +33,9 @@
# See http://www.hp.com/go/mlib
# ESSL - IBM's Engineering and Scientific Subroutine Library
-# ESSL_6464 - IBM's Engineering and Scientific Subroutine Library (int64)
-# ESSL_SMP - IBM's Engineering and Scientific Subroutine Library (smp)
-# ESSL_SMP_6464 - (smp + int64)
+# ESSL6464 - IBM's Engineering and Scientific Subroutine Library (int64)
+# ESSLSMP - IBM's Engineering and Scientific Subroutine Library (smp)
+# ESSLSMP6464 - (smp + int64)
# See http://www-03.ibm.com/systems/software/essl/
# MKL - Intel Math Kernel Library (dynamic interface)